# CLI

## lint

```{eval-rst}
.. autofunction:: deal._cli._lint.LintCommand
```

## decorate

```{eval-rst}
.. autofunction:: deal._cli._decorate.DecorateCommand
```

## test

```{eval-rst}
.. autofunction:: deal._cli._test.TestCommand
```

## memtest

```{eval-rst}
.. autofunction:: deal._cli._memtest.MemtestCommand
```

## stub

```{eval-rst}
.. autofunction:: deal._cli._stub.StubCommand
```

## prove

```{eval-rst}
.. autofunction:: deal._cli._prove.ProveCommand
```
